/*
 * opamp.c
 *
 * Created: 2017/06/28 11:23:00
 *  Author: M.Urushidani
 */ 

/* source management */
#define OPAMP_C


#include <avr/io.h>
#include <avr/interrupt.h>

/* local includes */
#include "config.h"           /* global configuration */
#include "common.h"           /* common header file */
#include "variables.h"        /* global variables */
#include "functions.h"        /* external functions */
#include "opamp.h"				//mu0704

uint8_t Mode_SW(void)
{
	uint8_t Mode_ID;
	DDRC = 0xF0;
	Mode_ID = PINC & 0x0F;
	return Mode_ID;
}

#ifdef OPAMP_MEASUREMENT
void Opamp_Check(void)
	{
		//uint16_t	v1;
		uint16_t	v0;
		//uint16_t	v2;
		uint16_t	vx;
		uint32_t	gain;
		uint16_t	db;
		
		CONT_DDR = ((1<<DUT_REF_CONT) | (1<<NOT_OP_POWER));
		CONT_PORT = (1<<DUT_REF_CONT);		// DUT-pin1 side, Opamp-ON

		LCD_Clear();
		LCD_EEString(OLoop_str);
		wait2s();

		v0 = ReadU_5ms(TP_AOP);
		
		CONT_PORT &= ~(1<<DUT_REF_CONT);	// DUT-ref3.5V side
		wait5s();
		
		vx = ReadU_5ms(TP_AOP);
		
		gain = 1000/(v0-vx);				//(v1-v2)/(v0-vx);
		db = 20*(3+log10(gain));			//20*log10(1000*gain);
		LCD_ClearLine2();
		DisplayValue(db,0,'d');
		LCD_Char('B');
		wait1s();
	}
#endif

/* ************************************************************************
 *   Regulator tool
 * ************************************************************************ */

#ifdef HW_REGULATOR

/*
 *  Regulator tool:
 *  - Voltage Regulator voltage measurement hardware option
 *  - use dedicated analog input (TP_REG) with 10:1 voltage divider
 */

void Regulator_Tool(void)
{
  //uint8_t                Run = 1;            /* control flag */
  //uint8_t                Counter;            /* length of key press */
  //uint8_t                Counter2 = 0;       /* time between two key presses */
  uint16_t               Value;              /* current value */
  //uint16_t               Min = UINT16_MAX;   /* minimal value */

  /* show info */
  LCD_Clear();
  LCD_EEString(Regulator_str);         /* display: Regulator */
  LCD_NextLine();
  LCD_Char('-');                   /* display "no value" */

  /* get voltage (10:1 voltage divider) */
  Value = ReadU(TP_REG);     /* special probe pin */
  Value /= 10;                 /* scale to 0.1V */

  /* display voltage */
  LCD_ClearLine2();
  DisplayValue(Value, -1, 'V');
  wait2s();
}

#endif

/* source management */
#undef OPAMP_C


